@@ -1,22 +1,18 @@
 # This file is part of Hypothesis, which may be found at
 # https://github.com/HypothesisWorks/hypothesis/
 #
-# Most of this work is copyright (C) 2013-2021 David R. MacIver
-# (david@drmaciver.com), but it contains contributions by others. See
-# CONTRIBUTING.rst for a full list of people who may hold copyright, and
-# consult the git log if you need to determine who owns an individual
-# contribution.
+# Copyright the Hypothesis Authors.
+# Individual contributors are listed in AUTHORS.rst and the git log.
 #
 # This Source Code Form is subject to the terms of the Mozilla Public License,
 # v. 2.0. If a copy of the MPL was not distributed with this file, You can
 # obtain one at https://mozilla.org/MPL/2.0/.
-#
-# END HEADER
 
 from hypothesis.strategies._internal import SearchStrategy
 from hypothesis.strategies._internal.collections import tuples
 from hypothesis.strategies._internal.core import (
     DataObject,
+    DrawFn,
     binary,
     booleans,
     builds,
@@ -82,6 +78,7 @@ __all__ = [
     "decimals",
     "deferred",
     "dictionaries",
+    "DrawFn",
     "emails",
     "fixed_dictionaries",
     "floats",
@@ -124,15 +121,19 @@ def _check_exports(_public):
 
     # Verify that all exported strategy functions were registered with
     # @declares_strategy.
+
+    existing_strategies = set(_strategies) - {"_maybe_nil_uuids"}
+
     exported_strategies = set(__all__) - {
         "DataObject",
+        "DrawFn",
         "SearchStrategy",
         "composite",
         "register_type_strategy",
     }
-    assert set(_strategies) == exported_strategies, (
-        set(_strategies) - exported_strategies,
-        exported_strategies - set(_strategies),
+    assert existing_strategies == exported_strategies, (
+        existing_strategies - exported_strategies,
+        exported_strategies - existing_strategies,
     )
 
 
